@@ -8,6 +8,7 @@ borders
 Functions for creating border pattern graphics.
 """
 
+
 from math import pi
 
 import cairo
@@ -23,6 +24,7 @@ def circles_pil(width, height, color):
     draw.ellipse((0, 0, width - 1, height - 1), fill=color)
     image.save('circles.png')
 
+
 def circles_pycairo(width, height, color):
     """ Implementation of circle border with PyCairo. """
 
@@ -33,14 +35,14 @@ def circles_pycairo(width, height, color):
 
     # draw a circle in the center
     ctx.new_path()
-    ctx.set_source_rgb(cairo_color.red, cairo_color.green, cairo_color.blue)  # blue
-    ctx.arc(width / 2, height / 2, width / 2, 0 , 2 * pi)
-    ctx.fill()  # stroke current path
+    ctx.set_source_rgb(cairo_color.red, cairo_color.green, cairo_color.blue)
+    ctx.arc(width / 2, height / 2, width / 2, 0, 2 * pi)
+    ctx.fill()
 
-    # save to PNG
-    surface.write_to_png('circles_pycairo.png')
+    surface.write_to_png('circles.png')
 
-def circles(width=12, height=12, color=rgb(255, 252, 229)):
+
+def circles(width=12, height=12, color=rgb(255, 255, 255)):
     """ Draws a repeatable circle border pattern. """
 
     circles_pycairo(width, height, color)
